diff --git a/Emby.Server.Implementations/LiveTv/Listings/SchedulesDirectDtos/LineupDto.cs b/Emby.Server.Implementations/LiveTv/Listings/SchedulesDirectDtos/LineupDto.cs
index b8f27a8ac7..52e920aa61 100644
--- a/Emby.Server.Implementations/LiveTv/Listings/SchedulesDirectDtos/LineupDto.cs
+++ b/Emby.Server.Implementations/LiveTv/Listings/SchedulesDirectDtos/LineupDto.cs
@@ -24,7 +24,7 @@ namespace Emby.Server.Implementations.LiveTv.Listings.SchedulesDirectDtos
///
/// Gets or sets the transport.
///
- [JsonPropertyName("transport.")]
+ [JsonPropertyName("transport")]
public string Transport { get; set; }
///
diff --git a/Emby.Server.Implementations/LiveTv/Listings/SchedulesDirectDtos/MapDto.cs b/Emby.Server.Implementations/LiveTv/Listings/SchedulesDirectDtos/MapDto.cs
index 8d45e8fff7..5140277b2c 100644
--- a/Emby.Server.Implementations/LiveTv/Listings/SchedulesDirectDtos/MapDto.cs
+++ b/Emby.Server.Implementations/LiveTv/Listings/SchedulesDirectDtos/MapDto.cs
@@ -34,15 +34,15 @@ namespace Emby.Server.Implementations.LiveTv.Listings.SchedulesDirectDtos
public int UhfVhf { get; set; }
///
/// Gets or sets the astc major.
///
- [JsonPropertyName("astcMajor")]
+ [JsonPropertyName("atscMajor")]
public int AtscMajor { get; set; }
///
/// Gets or sets the astc minor.
///
- [JsonPropertyName("astcMinor")]
+ [JsonPropertyName("atscMinor")]
public int AtscMinor { get; set; }
}
}
@@ -34,15 +34,15 @@ namespace Emby.Server.Implementations.LiveTv.Listings.SchedulesDirectDtos
public int UhfVhf { get; set; }
///
- /// Gets or sets the astc major.
+ /// Gets or sets the atsc major.
///
@@ -34,15 +34,15 @@ namespace Emby.Server.Implementations.LiveTv.Listings.SchedulesDirectDtos
public int AtscMajor { get; set; }
///
- /// Gets or sets the astc minor.
+ /// Gets or sets the atsc minor.
///